instrumenttools.Xylophone
=========================

.. abjad-lineage:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone

.. autoclass:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Xylophone.Xylophone.Xylophone.__repr__
   :noindex:
